@@ -1,21 +1,23 @@
 package MooseX::MethodAttributes::Role::Meta::Class;
-BEGIN {
-  $MooseX::MethodAttributes::Role::Meta::Class::AUTHORITY = 'cpan:FLORA';
-}
-BEGIN {
-  $MooseX::MethodAttributes::Role::Meta::Class::VERSION = '0.25';
-}
 # ABSTRACT: metaclass role for storing code attributes
 
+our $VERSION = '0.31';
+
 use Moose::Role;
 use Moose::Util qw/find_meta does_role/;
 
-use namespace::clean -except => 'meta';
+use namespace::autoclean;
 
 with qw/
     MooseX::MethodAttributes::Role::Meta::Map
 /;
 
+#pod =method get_method_with_attributes_list
+#pod
+#pod Gets the list of meta methods for local methods of this class that have
+#pod attributes in the order they have been registered.
+#pod
+#pod =cut
 
 sub get_method_with_attributes_list {
     my ($self) = @_;
@@ -41,6 +43,13 @@ sub get_method_with_attributes_list {
     } @methods;
 }
 
+#pod =method get_all_methods_with_attributes
+#pod
+#pod Gets the list of meta methods of local and inherited methods of this class,
+#pod that have attributes. Base class methods come before subclass methods. Methods
+#pod of one class have the order they have been declared in.
+#pod
+#pod =cut
 
 sub get_all_methods_with_attributes {
     my ($self) = @_;
@@ -57,6 +66,32 @@ sub get_all_methods_with_attributes {
     } reverse $self->linearized_isa;
 }
 
+#pod =method get_nearest_methods_with_attributes
+#pod
+#pod The same as get_all_methods_with_attributes, except that methods from parent classes
+#pod are not included if there is an attribute-less method in a child class.
+#pod
+#pod For example, given:
+#pod
+#pod     package BaseClass;
+#pod
+#pod     sub foo : Attr {}
+#pod
+#pod     sub bar : Attr {}
+#pod
+#pod     package SubClass;
+#pod     use base qw/BaseClass/;
+#pod
+#pod     sub foo {}
+#pod
+#pod     after bar => sub {}
+#pod
+#pod C<< SubClass->meta->get_all_methods_with_attributes >> will return
+#pod C<< BaseClass->meta->get_method('foo') >> for the above example, but
+#pod this method will not, and will return the wrapped bar method, whereas
+#pod C<< get_all_methods_with_attributes >> will return the original method.
+#pod
+#pod =cut
 
 sub get_nearest_methods_with_attributes {
     my ($self) = @_;
@@ -89,16 +124,20 @@ foreach my $type (qw/after before around/) {
 
 1;
 
-
 __END__
+
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
 MooseX::MethodAttributes::Role::Meta::Class - metaclass role for storing code attributes
 
+=head1 VERSION
+
+version 0.31
+
 =head1 METHODS
 
 =head2 get_method_with_attributes_list
@@ -109,13 +148,13 @@ attributes in the order they have been registered.
 =head2 get_all_methods_with_attributes
 
 Gets the list of meta methods of local and inherited methods of this class,
-that have attributes. Baseclass methods come before subclass methods. Methods
+that have attributes. Base class methods come before subclass methods. Methods
 of one class have the order they have been declared in.
 
 =head2 get_nearest_methods_with_attributes
 
 The same as get_all_methods_with_attributes, except that methods from parent classes
-are not included if there is an attributeless method in a child class.
+are not included if there is an attribute-less method in a child class.
 
 For example, given:
 
@@ -134,9 +173,20 @@ For example, given:
 
 C<< SubClass->meta->get_all_methods_with_attributes >> will return
 C<< BaseClass->meta->get_method('foo') >> for the above example, but
-this method will not, and will return the wrapped bar method, wheras
+this method will not, and will return the wrapped bar method, whereas
 C<< get_all_methods_with_attributes >> will return the original method.
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=MooseX-MethodAttributes>
+(or L<bug-MooseX-MethodAttributes@rt.cpan.org|mailto:bug-MooseX-MethodAttributes@rt.cpan.org>).
+
+There is also a mailing list available for users of this distribution, at
+L<http://lists.perl.org/list/moose.html>.
+
+There is also an irc channel available for users of this distribution, at
+irc://irc.perl.org/#moose.
+
 =head1 AUTHORS
 
 =over 4
@@ -151,12 +201,11 @@ Tomas Doran <bobtfish@bobtfish.net>
 
 =back
 
-=head1 COPYRIGHT AND LICENSE
+=head1 COPYRIGHT AND LICENCE
 
-This software is copyright (c) 2011 by Florian Ragwitz.
+This software is copyright (c) 2009 by Florian Ragwitz.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
