@@ -1,17 +1,13 @@
 package MooseX::MethodAttributes::Role::Meta::Method::MaybeWrapped;
-BEGIN {
-  $MooseX::MethodAttributes::Role::Meta::Method::MaybeWrapped::AUTHORITY = 'cpan:FLORA';
-}
-BEGIN {
-  $MooseX::MethodAttributes::Role::Meta::Method::MaybeWrapped::VERSION = '0.25';
-}
 # ABSTRACT: proxy attributes of wrapped methods if their metaclass supports it
 
+our $VERSION = '0.31';
+
 use Moose::Role;
 use Moose::Util qw/does_role/;
 use MooseX::MethodAttributes::Role::Meta::Method::Wrapped;
 
-use namespace::clean -except => 'meta';
+use namespace::autoclean;
 
 override wrap => sub {
     my $self = super;
@@ -28,14 +24,30 @@ override wrap => sub {
 1;
 
 __END__
+
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
 MooseX::MethodAttributes::Role::Meta::Method::MaybeWrapped - proxy attributes of wrapped methods if their metaclass supports it
 
+=head1 VERSION
+
+version 0.31
+
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=MooseX-MethodAttributes>
+(or L<bug-MooseX-MethodAttributes@rt.cpan.org|mailto:bug-MooseX-MethodAttributes@rt.cpan.org>).
+
+There is also a mailing list available for users of this distribution, at
+L<http://lists.perl.org/list/moose.html>.
+
+There is also an irc channel available for users of this distribution, at
+irc://irc.perl.org/#moose.
+
 =head1 AUTHORS
 
 =over 4
@@ -50,12 +62,11 @@ Tomas Doran <bobtfish@bobtfish.net>
 
 =back
 
-=head1 COPYRIGHT AND LICENSE
+=head1 COPYRIGHT AND LICENCE
 
-This software is copyright (c) 2011 by Florian Ragwitz.
+This software is copyright (c) 2009 by Florian Ragwitz.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
